@@ -986,14 +986,15 @@ class WordToken(models.Model):
             return False
         return True
 
-    def getAnalysisLines(self,form):
+    def getAnalysisLines(self,output_form):
+        form = output_form
+        wanted_lines = output_form.get_wanted_fields()
         if self.Output is not None:
             #outline = {x: self.Output[x] for x in self.Output if x not in form['force_fetch']}
             outline = copy.copy(self.Output)
         else:
             outline = {}
 
-        wanted_fields =[]
         if outline == {}:
             outline['Word'] = self.WordType.Label
             outline['Token'] = self.pk
@@ -1002,28 +1003,23 @@ class WordToken(models.Model):
             outline['PrevCons'] = prevSound
             outline['FollCons'] = follSound
             outline['Speaker'] = str(self.Dialog.Speaker)
-        wanted_fields.extend(['Word','Token','Vowel','PrevCons','FollCons','Speaker'])
         if form['segmentalDurations']:
             if 'VowDur' not in outline:
                 outline['VowDur'] = end-beg
                 outline['OtherDur'] = self.getDuration()- outline['VowDur']
-            wanted_fields.extend(['VowDur','OtherDur'])
         if form['speakingRates']:
             if 'PrevSpeakRate' not in outline:
                 outline['PrevSpeakRate'] = self.getPreviousSpeakingRate()
                 outline['FollSpeakRate'] = self.getFollowingSpeakingRate()
                 outline['AvgSpeakRate'] = self.Dialog.Speaker.getAvgSpeakingRate()
-            wanted_fields.extend(['PrevSpeakRate','FollSpeakRate','AvgSpeakRate'])
         if form['contextProbs']:
             if 'PrevCondProb' not in outline:
                 outline['PrevCondProb'] = self.getPreviousCondProb()
                 outline['FollCondProb'] = self.getFollowingCondProb()
-            wanted_fields.extend(['PrevCondProb','FollCondProb'])
         if form['repetitions']:
             if 'Repetitions' not in outline:
                 outline['Repetitions'] = self.getRepetitions()
                 outline['wasRepeatedRecently'] = self.getRecentRepetition()
-            wanted_fields.extend(['Repetitions','wasRepeatedRecently'])
         if form['wasRepeated']:
             if 'Repetitions' not in outline:
                 outline['Repetitions'] = self.getRepetitions()
@@ -1032,95 +1028,77 @@ class WordToken(models.Model):
                     outline['wasRepeated'] = 'True'
                 else:
                     outline['wasRepeated'] = 'False'
-            wanted_fields.extend(['wasRepeated'])
 
 
         if 'B' in form['category']:
             if 'BuckeyeCategory' not in outline:
                 outline['BuckeyeCategory'] = self.Category.Label
-            wanted_fields.extend(['BuckeyeCategory'])
         if 'C' in form['category']:
             if 'CelexCategory' not in outline:
                 outline['CelexCategory'] = lookupCat(self.WordType.Label)
-            wanted_fields.extend(['CelexCategory'])
 
         if form['wordDuration']:
             if 'WordDuration' not in outline:
                 outline['WordDuration'] = self.getDuration()
                 outline['BaselineDur'] = self.WordType.getBaseDuration()
-            wanted_fields.extend(['WordDuration','BaselineDur'])
 
         if 'B' in form['frequency']:
             if 'BuckeyeFrequency' not in outline:
                 outline['BuckeyeFrequency'] = self.WordType.getFreq()
-            wanted_fields.extend(['BuckeyeFrequency'])
         if 'C' in form['frequency']:
             if 'CelexFrequency' not in outline:
                 outline['CelexFrequency'] = lookupFreq(self.WordType.Label)
-            wanted_fields.extend(['CelexFrequency'])
 
         if form['gender']:
             if 'SpeakerGender' not in outline:
                 outline['SpeakerGender'] = self.Dialog.Speaker.Gender
-            wanted_fields.extend(['SpeakerGender'])
         if form['age']:
             if 'SpeakerAge' not in outline:
                 outline['SpeakerAge'] = self.Dialog.Speaker.Age
-            wanted_fields.extend(['SpeakerAge'])
 
         if form['orthoLength']:
             if 'OrthoLength' not in outline:
                 outline['OrthoLength'] = len(self.WordType.Label)
-            wanted_fields.extend(['OrthoLength'])
         if form['phonoLength']:
             if 'PhonoLength' not in outline:
                 outline['PhonoLength'] = self.WordType.UR.count()
-            wanted_fields.extend(['PhonoLength'])
         if 'B' in form['nd']:
             if 'BuckeyeNeighDen' not in outline:
                 outline['BuckeyeNeighDen'],outline['BuckeyeFWND'] = self.WordType.getNDs()
-            wanted_fields.extend(['BuckeyeNeighDen','BuckeyeFWND'])
         if 'PS' in form['nd']:
             if 'PhonoStatsNeighDen' not in outline:
                 outline['PhonoStatsNeighDen'] = getNeighCount(self.WordType.getStrUR(),no_stress=True)
-            wanted_fields.extend(['PhonoStatsNeighDen'])
 
         if 'VB' in form['phonotactic']:
             if 'BuckeyeSPhoneProb' not in outline:
                 outline['BuckeyeSPhoneProb'],outline['BuckeyeBiPhoneProb'] = self.WordType.getPhonoProb()
-            wanted_fields.extend(['BuckeyeSPhoneProb','BuckeyeBiPhoneProb'])
         if 'B' in form['phonotactic']:
             if 'PhonoStatsBlickPhono' not in outline:
                 outline['PhonoStatsBlickPhono'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=True,no_stress=True)
-            wanted_fields.extend(['PhonoStatsBlickPhono'])
         if 'VP' in form['phonotactic']:
             if 'PhonoStatsSPhoneProb' not in outline:
                 outline['PhonoStatsSPhoneProb'],outline['PhonoStatsBiPhoneProb'] = getPhonotacticProb(self.WordType.getStrUR(),use_blick=False,no_stress=True)
-            wanted_fields.extend(['PhonoStatsSPhoneProb','PhonoStatsBiPhoneProb'])
+
         if form['prev_sem_pred']:
             if 'PrevSemPred' not in outline:
                 outline['PrevSemPred'] = self.getPrevSemPred()
             if 'ImmedPrevSemPred' not in outline:
                 outline['ImmedPrevSemPred'] = self.getImmediatePrevSemPred()
                 outline['IntermedPrevSemPred'] = self.getIntermedPrevSemPred()
-            wanted_fields.extend(['PrevSemPred','ImmedPrevSemPred','IntermedPrevSemPred'])
         if form['foll_sem_pred']:
             if 'FollSemPred' not in outline:
                 outline['FollSemPred'] = self.getFollSemPred()
             if 'ImmedFollSemPred' not in outline:
                 outline['ImmedFollSemPred'] = self.getImmediateFollSemPred()
                 outline['IntermedFollSemPred'] = self.getIntermedFollSemPred()
-            wanted_fields.extend(['FollSemPred','ImmedFollSemPred','IntermedFollSemPred'])
         if form['pause_dist']:
             if 'DistFollPause' not in outline:
                 outline['DistFollPause'] = self.getFollDistToPause()
             if 'DistPrevPause' not in outline:
                 outline['DistPrevPause'] = self.getPrevDistToPause()
-            wanted_fields.extend(['DistFollPause','DistPrevPause'])
         if form['placeInDialog']:
             if 'placeInDialog' not in outline:
                 outline['placeInDialog'] = self.getDialogPlace()
-            wanted_fields.extend(['placeInDialog'])
         if form['measure'] == 'S':
             if 'formants' not in outline:
                 ceiling = self.getCeiling()
@@ -1147,18 +1125,18 @@ class WordToken(models.Model):
                     outline['F2'] = 'NA'
                 else:
                     outline['F2'] = F2
-            wanted_fields.extend(['F1','F2'])
+            wanted_fields += ['F1','F2']
             if form['measure'] == 'D' and 'NA' not in [outline['F1'],outline['F2']]:
                 if form['DispersionFromAH']:
                     if 'AHDispersion' not in outline:
                         center = self.Dialog.Speaker.getAHCenter()
                         outline['AHDispersion'] = math.sqrt(math.pow(outline['F1']-center[0],2)+math.pow(outline['F2']-center[1],2))
-                    wanted_fields.extend(['AHDispersion'])
+                    wanted_fields += ['AHDispersion']
                 else:
                     if 'Dispersion' not in outline:
                         center = self.Dialog.Speaker.getCenter()
                         outline['Dispersion'] = math.sqrt(math.pow(outline['F1']-center[0],2)+math.pow(outline['F2']-center[1],2))
-                    wanted_fields.extend(['Dispersion'])
+                    wanted_fields += ['Dispersion']
             elif form['measure'] == 'D':
                 outline['Dispersion'] = 'NA'
         to_out = [{k:outline[k] for k in outline if k in wanted_fields}]
